#
# spec file for package open-vm-tools
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# exclude AMD PCnet32 LANCE pci.id from Supplements list [bnc#397554]
%define __find_supplements sh -c '/usr/lib/rpm/find-supplements %{name} | grep -v pci:v00001022d00002000'

%if 0%{?suse_version} <= 1210
# Modules to be built up to openSUSE 12.1, possibly not building on newer versions.
%define vm_modules1210 vmxnet
%endif

# Modules that have to be build up to version 12.2 (Last checked on 2012-02-05 with kernel 3.2.0)
%define vm_modules vmci vmblock vmhgfs vmsync vsock %{?vm_modules1210}

# X modules are lower prio upstream and once in a while fail. Offer an easy way to enable/disable them.
%define with_X 1

Name:           open-vm-tools
Version:        2012.8.8.1
%define _version 8.8.1
Release:        32.1
%define         svn_rev 528969
Summary:        Open Virtual Machine Tools
License:        BSD-3-Clause ; GPL-2.0 ; LGPL-2.1
Group:          System/Emulators/PC
Url:            http://open-vm-tools.sourceforge.net/
Source:         http://sourceforge.net/projects/open-vm-tools/files/open-vm-tools/stable-8.8.x/%{name}-%{_version}-%{svn_rev}.tar.gz
Source1:        vmtoolsd
Source2:        vmware-user-autostart.desktop
Source4:        open-vm-tools.permissions
Source5:        vmware-user-autostart-wrapper
Source6:        open-vm-tools-modprobe.conf
Source7:        tools.conf
Source98:       preamble
Patch0:         vmhgfs-2011.12.20.patch
BuildRequires:  gcc-c++
# don't use pkgconfig(gtk+-2.0) so we can build on SLE
BuildRequires:  gtk2-devel
BuildRequires:  gtkmm2-devel
BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  libdnet-devel
BuildRequires:  libicu-devel
BuildRequires:  module-init-tools
BuildRequires:  pcre-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# liburiparser was not present before 11.0
%if 0%{?suse_version} >= 1100
BuildRequires:  liburiparser-devel
%endif
BuildRequires:  pam-devel
Requires:       vmware-guest-kmp
Supplements:    modalias(pci:v000015ADd*sv*sd*bc*sc*i*)
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
Requires(pre):  permissions
ExclusiveArch:  %ix86 x86_64

%suse_kernel_module_package -n vmware-guest -p %{SOURCE98} xen um

%description
Open Virtual Machine Tools (open-vm-tools) are the open source
implementation of VMware Tools. They are a set of guest operating
system virtualization components that enhance performance and user
experience of virtual machines. As virtualization technology rapidly
becomes mainstream, each virtualization solution provider implements
their own set of tools and utilities to supplement the guest virtual
machine. However, most of the implementations are proprietary and are
tied to a specific virtualization platform.

With the Open Virtual Machine Tools project, we are hoping to solve
this and other related problems. The tools are currently composed of
kernel modules for Linux and user-space programs for all VMware
supported Unix-like guest operating systems. They provide several
useful functions like:

* File transfer between a host and guest

* Improved memory management and network performance under
   virtualization

* General mechanisms and protocols for communication between host and
guests and from guest to guest

%package -n vmware-guest-KMP
Summary:        Open Virtual Machine Tools - for VM GUESTS
Group:          System/Emulators/PC

%description -n vmware-guest-KMP
Open Virtual Machine Tools (open-vm-tools) are the open source
implementation of VMware Tools. They are a set of guest operating
system virtualization components that enhance performance and user
experience of virtual machines. As virtualization technology rapidly
becomes mainstream, each virtualization solution provider implements
their own set of tools and utilities to supplement the guest virtual
machine. However, most of the implementations are proprietary and are
tied to a specific virtualization platform.

With the Open Virtual Machine Tools project, we are hoping to solve
this and other related problems. The tools are currently composed of
kernel modules for Linux and user-space programs for all VMware
supported Unix-like guest operating systems. They provide several
useful functions like:

* File transfer between a host and guest

* Improved memory management and network performance under
   virtualization

* General mechanisms and protocols for communication between host and
guests and from guest to guest

%if %{with_X}

%package gui
Summary:        Open Virtual Machine Tools - GUI
Group:          System/Emulators/PC
Requires:       open-vm-tools
Supplements:    packageand(open-vm-tools:xorg-x11)
Requires(pre):  permissions

%description gui
GUI Toolbox for Open Virtual Machine Tools
%endif

%package -n libvmtools0
Summary:        Open Virtual Machine Tools - shared library
Group:          System/Libraries

%description -n libvmtools0
This is a shared library used by several Open VM Tools components,
such as vmware-toolbox-cmd and vmtoolsd (and its plugins).

%package -n libvmtools-devel
Summary:        Open Virtual Machine Tools - Development headers
Group:          Development
Requires:       libvmtools0 = %{version}

%description -n libvmtools-devel
Those are the development headers for libvmtools. They are needed
if you intend to create own plugins for vmtoolsd.

%prep
%setup -q -n %{name}-%{_version}-%{svn_rev}
%patch0 -p1
chmod -x AUTHORS COPYING ChangeLog NEWS README
# fix for an rpmlint warning regarding wrong line feeds
sed -i -e "s/\r//" README

%build
# disable warning unused-but-set-variable which will raise error because of -Werror
# disable warning deprecated-declarations which will raise error because of -Werror
# (this is because of 'g_static_mutex_init' usage which is now deprecated)
%if 0%{?suse_version} > 1110
export CFLAGS="%{optflags} -Wno-unused-but-set-variable -Wno-deprecated-declarations -fPIE"
export CPPFLAGS="%{optflags} -Wno-unused-but-set-variable -Wno-deprecated-declarations -fPIE"
%else
export CFLAGS="%{optflags} -Wno-deprecated-declarations -fPIE"
export CPPFLAGS="%{optflags} -Wno-deprecated-declarations -fPIE"
%endif
export LDFLAGS="-pie"
# comments in a continued line seem not to work... shame
# --disable-unity : liburiparser was not present before 11.0
%configure \
%if 0%{?suse_version} < 1140
    --disable-unity \
%endif
    --without-kernel-modules \
    --without-root-privileges \
    --without-procps \
%if %{with_X}
    --with-x \
%else
    --without-x \
%endif
    --disable-dependency-tracking \
    --disable-static
make

TOPDIR=$PWD
cd ..
mkdir -p obj
for flavor in %{flavors_to_build}; do
  rm -rf obj/$flavor
  cp -r %{name}-%{_version}-%{svn_rev} obj/$flavor
  pushd obj/$flavor
  for module in %{vm_modules}; do
    pushd modules/linux/$module
    if [ -f ../vmci/Module.symvers ]; then
       cp ../vmci/Module.symvers .
    fi
    make -C /usr/src/linux-obj/%{_target_cpu}/$flavor modules M=$PWD VM_CCVER=$(gcc -dumpversion) HEADER_DIR="/usr/src/linux-obj/$(uname -i)/default/include" SRCROOT=$PWD OVT_SOURCE_DIR=$TOPDIR
    popd
  done
  popd
done

%install
# let's use the kernel's own modules_install routine
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
pushd ..
for flavor in %{flavors_to_build}; do
  pushd obj/$flavor
  for module in %{vm_modules}; do
    make -C /usr/src/linux-obj/%_target_cpu/$flavor modules_install M=$PWD/modules/linux/$module
  done
  popd
done
popd

# fix some rights on the kernel modules, to have a complete -debuginfo package
chmod u+x %{buildroot}/lib/modules/*/updates/*

%if 0%{?suse_version} > 1110
%make_install
%else
%makeinstall
%endif
# Clean up the *.la files make install put all around
find %{buildroot} -name '*.la' -delete -print

# install the vmtoolsd init script and also it's rcvmtoolsd softlink
install -D -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/vmtoolsd
ln -sf ../../etc/init.d/vmtoolsd %{buildroot}%{_sbindir}/rcvmtoolsd

%if %{with_X}
# vmware-user is started by vmware-user-suid-wrapper by xdg-autostart
# unfortunately, vmware-user-suid-wrapper does not wait for it's block device
# to appear. For this reason we have now a vmware-user-autostart-wrapper
# which checks for /proc/fs/vmblock/dev to appear and then starts vmware-user-suid-wrapper
install -D -m 0755 %{SOURCE5} %{buildroot}%{_bindir}/vmware-user-autostart-wrapper
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user-autostart.desktop

# Install the default tools.conf
install -D -m 0644 %{S:7} %{buildroot}%{_sysconfdir}/vmware-tools/tools.conf

# In case we install vmware-user-suid-wrapper, we need to give it 4755 permissions.
#install -D -m 0644 %%{S:4} %%{buildroot}%%{_sysconfdir}/permissions.d/open-vm-tools

# We have our own 'safe' autostart wrapper, which checks for modules to start in autologin mode...
# Thus we drop the 'original' autostartup
rm %{buildroot}%{_sysconfdir}/xdg/autostart/vmware-user.desktop

# handle the .destop files for translations
%suse_update_desktop_file vmware-user-autostart
%endif

# modprobe configuration for vmnics.
install -D -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/modprobe.d/50-vmnics.conf

# fix a link pointing to the buildroot for mount.vmhgfs
( cd %{buildroot}/sbin; rm mount.vmhgfs; ln -s ..%{_sbindir}/mount.vmhgfs )

# the script installs some binaries into /usr/share/open-vm-tools which are just some tests.
# So we drop them for the moment. Upstream has been informed about this.
rm -r %{buildroot}%{_datadir}/%{name}

%post
%if 0%{?suse_version} <= 1130
%run_permissions
%else
%set_permissions /usr/bin/vmware-user-suid-wrapper
%endif
/sbin/ldconfig
%{fillup_and_insserv -Y vmtoolsd}

%if %{with_X}

%verifyscript gui
%verify_permissions -e /usr/bin/vmware-user-suid-wrapper

%post gui
%if 0%{?suse_version} <= 1130
%run_permissions
%else
%set_permissions /usr/bin/vmware-user-suid-wrapper
%endif

%endif

%preun
# stop service with the old name (if exists) on update (something like %%stop_on_update)
test -n "$FIRST_ARG" || FIRST_ARG=$1
if test "$FIRST_ARG" -ge 1 ; then
    test -f /etc/sysconfig/services && . /etc/sysconfig/services
    if test "$YAST_IS_RUNNING" != "instsys" ; then
        /etc/init.d/vmware-guestd stop &> /dev/null || :
    fi
fi
%stop_on_removal vmtoolsd
vmware-rpctool "tools.set.version 0" || :

%postun
%restart_on_update vmtoolsd
%insserv_cleanup
/sbin/ldconfig

%post -n libvmtools0 -p /sbin/ldconfig

%postun -n libvmtools0 -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_bindir}/vmtoolsd
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/common
%dir %{_libdir}/%{name}/plugins/vmsvc
%if %{with_X}
%dir %{_libdir}/%{name}/plugins/vmusr
%endif
%{_libdir}/%{name}/plugins/vmsvc/libguestInfo.so
%{_libdir}/%{name}/plugins/vmsvc/libpowerOps.so
%{_libdir}/%{name}/plugins/vmsvc/libtimeSync.so
%{_libdir}/%{name}/plugins/vmsvc/libvmbackup.so
%{_libdir}/%{name}/plugins/common/libhgfsServer.so
%{_libdir}/%{name}/plugins/common/libvix.so
%{_bindir}/vmware-checkvm
%{_bindir}/vmware-hgfsclient
%{_bindir}/vmware-rpctool
%{_bindir}/vmware-toolbox-cmd
%{_bindir}/vmware-xferlogs
%{_sbindir}/mount.vmhgfs
/sbin/mount.vmhgfs
%config(noreplace) %{_sysconfdir}/pam.d/vmtoolsd
%dir %{_sysconfdir}/vmware-tools
%dir %{_sysconfdir}/vmware-tools/scripts
%dir %{_sysconfdir}/vmware-tools/scripts/vmware
%{_sysconfdir}/vmware-tools/plugins
%{_sysconfdir}/vmware-tools/poweroff-vm-default
%{_sysconfdir}/vmware-tools/poweron-vm-default
%{_sysconfdir}/vmware-tools/resume-vm-default
%{_sysconfdir}/vmware-tools/scripts/vmware/network
%{_sysconfdir}/vmware-tools/statechange.subr
%{_sysconfdir}/vmware-tools/suspend-vm-default
%config(noreplace) %{_sysconfdir}/vmware-tools/tools.conf
%{_sysconfdir}/vmware-tools/vm-support
%{_sysconfdir}/init.d/vmtoolsd
%{_sysconfdir}/modprobe.d/50-vmnics.conf
%{_sbindir}/rcvmtoolsd
%exclude %{_libdir}/*.so

%if %{with_X}

%files gui
%defattr(-, root, root)
%{_bindir}/vmware-toolbox
%{_sysconfdir}/xdg/autostart/vmware-user-autostart.desktop
#%%{_sysconfdir}/permissions.d/open-vm-tools
%verify(not mode) %attr(0755,root,root) %{_bindir}/vmware-user-suid-wrapper
%{_libdir}/%{name}/plugins/vmusr/libdesktopEvents.so
%{_libdir}/%{name}/plugins/vmusr/libdndcp.so
%{_libdir}/%{name}/plugins/vmusr/libresolutionSet.so
%if 0%{?suse_version} >= 1140
%{_libdir}/%{name}/plugins/vmusr/libunity.so
%endif
%{_libdir}/%{name}/plugins/vmusr/libvixUser.so
%{_bindir}/vmware-user-autostart-wrapper
%endif

%files -n libvmtools0
%defattr(-, root, root)
%{_libdir}/libvmtools.so.*
%{_libdir}/libguestlib.so.*
%{_libdir}/libhgfs.so.*

%files -n libvmtools-devel
%defattr(-,root,root)
%{_includedir}/vmGuestLib
%{_libdir}/*.so
%{_libdir}/pkgconfig/vmguestlib.pc

%changelog
* Thu Apr 19 2012 dimstar@opensuse.org
- Call the version 2012.8.8.1, which ensures we can updated from
  the last published 2012.05.xx version.
* Fri Mar 30 2012 dimstar@opensuse.org
- Build vmci as first module and copy Modules.symvers to source of
  all subsequent modules to be built. Fixes issues where vmhgfs for
  example does not have all symbols available and fails to load
  [bnc#703959].
* Fri Mar 30 2012 dimstar@opensuse.org
- Add a tools.conf to the package. All settings are left to default
  except [guestinfo] / disable-perf-mon=1, which resolves
  bnc#698181.
* Thu Mar 15 2012 prusnak@opensuse.org
- added call to vmware-rpctool in %%preun to unset the installed
  version [bnc#748517]
* Sun Feb  5 2012 dimstar@opensuse.org
- Add vmhgfs-2011.12.20.patch: Fix build of vmhgfs module with
  kernel 3.2.
- Update FSF address part in vmtoolsd header.
* Tue Jan 24 2012 prusnak@opensuse.org
- Update to version 8.8.1 (Stable series):
  * Updated code for compatibility with newer Linux kernel releases
    and with newer NetworkManager releases.
- dropped vmxnet+kernel-3.0 (not needed anymore)
- build with PIE [bnc#743130]
* Wed Sep 21 2011 dimstar@opensuse.org
- Update to version 8.8.0 (Stable series):
  + This release of open-vm-tools matches the VMware Tools package
    released with Workstation 8.0 and Fusion 4.0.
    It's targeted at desktop users who want the latest features in
    (VMware's) Unity, HGFS and drag & drop support.
- Add open-vm-tools-vmxnet+kernel-3.0.patch: HAVE_NETDEV_PRIV is
  gone in kernel 3.0 and netdev_priv is in kernel since 2.6.6.
- use set_permissions instead of run_permissions on 11.4+
* Thu Jul 21 2011 dimstar@opensuse.org
- Update to version 2011.07.19:
  + Fix an issue in the HGFS driver that could lead to a kernel
    panic.
  + Update some code to support new compiler and kernel versions.
  + Minor bug fixes and code cleanup.
- Changes from version 2011.06.27:
  + A few enhancements to Unity: XFCE support, better interaction
    with "the other" (Ubuntu's) Unity and compositing window
    managers, better X error handling, and a few bug fixes.
  + few bug fixes in HGFS, and minor bug fixes in other components.
  + Otherwise, mostly code cleanup.
* Thu Jun  2 2011 prusnak@opensuse.org
- updated to 2011.05.27:
  + Mostly cleanups and a few bug fixes.
- fixes [bnc#673267] [bnc#690491]
* Tue May 31 2011 prusnak@opensuse.org
- use -Wno-unused-but-set in optflags so it will not fail build
  while using -Werror
* Wed May 25 2011 prusnak@opensuse.org
- added check in initscript whether VMTOOLSUSER_BIN exists
* Fri Apr 29 2011 dimstar@opensuse.org
- Udpate to version 2011.04.25:
  + Mostly cleanups and small bug fixes in this release.
  + Logging is enabled by default in vmtoolsd, writing to syslog.
    The default log level is not chatty, so few messages should
    make it to syslog during normal operation.
  + The GUI version of the toolbox was removed.
* Wed Apr 27 2011 dimstar@opensuse.org
- Extend the init script to detect the name of the balloon driver,
  which changed several times in the kernel.
* Thu Apr 14 2011 dimstar@opensuse.org
- Update to 2011.03.28:
  + HGFS mounter and vmusr's suid wrapper were changed to avoid
    issues with symlink attacks. A new mount utility for vmblock on
    Solaris and FreeBSD was added.
  + The VMCI driver was thoroughly reworked so that it can serve as
    both the host and guest VMCI driver. This is mostly targeted at
    supporting nested VMs.
  + vmusr got better integration with X's session manager,
    including proper cleanup during session teardown.
  + Unity has been enhanced to better handle some desktop
    environments.
  + Many small bug fixes in other areas, including updates for
    newer Linux kernels.
- Changes from 2011.02.23:
  + Some copy & paste issues with KDE were fixed.
  + Mostly cleanups and bug fixes, with a few build enhancements.
- Changes from 2011.01.24:
  + Mostly cleanups and bug fixes.
  + Install code fixed to handle translation catalogs correctly.
- No longer care for missing modules on openSUSE 11.2. It is EOL in
  a few weeks. As a consequence, remove the sources (they are in
  current kernels):
  + pvscsi.tar.bz2
  + vmxnet3.tar.bz2
  + vmemctl.tar.bz2
- Fix some lint warnings: obsolete only <, not <=, Add PreReq:
  permissions to the -gui package.
* Thu Apr 14 2011 dimstar@opensuse.org
- Fix build with Factory: verify the list of modules that are not
  yet merged into the main kernel.
* Wed Dec 22 2010 dimstar@opensuse.org
- Update to version 2010.12.19:
  + New version of DnD code lands in open-vm-tools. The host part
    of the new DnD protocol is not available yet in VMware
    products, though.
  + vmtoolsd gets some new functionality to support new features
    being developed internally.
  + vmxnet driver for FreeBSD fixed to allow changing the MAC
    address.
  + lots of bug fixes and other cleanups in various areas.
- Re-enable building of X dependenices (with_X 1)
- Disable unity on openSUSE < 11.4. It requires glib >= 2.24.
* Thu Nov 25 2010 dimstar@opensuse.org
- Re-Inject pvscsi for older kernel builds.
* Mon Nov 22 2010 dimstar@opensuse.org
- Update to version 2010-11-17:
  + Mostly cleanups and bug fixes.
  + vmxnet3 on Solaris now supports jumbo frames.
- For all older updates, please see NEWS.
- Add an easy way to enable/disable X tools. Those currently fail
  to build.
- Drop open-vm-tools-libpng14.patch: upstream fixed.
* Mon Jun  7 2010 dimstar@opensuse.org
- Add vmmemctl.tar.bz2, extracted from open-vm-tools 2010.02.23.
* Mon May 31 2010 dimstar@opensuse.org
- Better logic to easily disable modules that got inlcluded in the
  Linux Kernel, for bnc#605085.
* Thu Apr 22 2010 dimstar@opensuse.org
- Re-introduce vmxnet3 on openSUSE <= 11.2. Up to then we have
  kernel 2.26.31, which does not bring the vmxnet3 driver yet.
  The driver itself is the last one shipped with open-vm-tools,
  version 2009.12.16.
* Wed Apr 21 2010 dimstar@opensuse.org
- Send SIGUSR1 to vmware-user process when the services are being
  stopped. This possibly solves bnc#544400.
* Wed Apr  7 2010 dimstar@opensuse.org
- Add open-vm-tools-libpng14.patch to fix build with libpng 1.4.
* Wed Mar 24 2010 dimstar@opensuse.org
- Update to 2010.03.20:
  + New i18n support for Tools; it is based on VMware's internal
    tools
  + Logging infrastructure has been enhanced and now supports
    rotation
  + Bug fixes in several areas (DnD, backup support, thread safety)
  + Updates in Linux kernel modules for compatibility with newer
    kernels.
  + New functionality in the Unity support code.
* Tue Mar 23 2010 dimstar@opensuse.org
- Disabled vmxnet3 building. this only did not give an error anyhow
  as there was a typo, thus having the module already disabled for
  quite some time.
- bnc#590329: Re-add lost 50-vmnics.conf file.
* Thu Feb 25 2010 dominique.leuenberger@tmf-group.com
- Update to 2010.02.23:
  + Mostly bug fixes, cleanups and code refactoring.
* Wed Feb 10 2010 dimstar@opensuse.org
- Update to 2010.01.19:
  + Linux modules have been updated to compile on newer kernels
  + Solaris modules now should compile on OpenSolaris
    (tested on 2009.06).
  + Other than those, mostly bug fixes and minor refactoring.
* Wed Jan  6 2010 dimstar@opensuse.org
- Update to 2009.12.16:
  + Some improvements to vmtoolsd, base libraries and and the
    plugin interface.
  + Some library refactoring: use new lock library, changes to
    support compilation of some code on ARM.
  + some fixes in configure.ac to try to correctly support newer
    distros.
  + vsock/vmci improvements.
  + bug fixes in the vmxnet / vmxnet3 drivers, and FreeBSD's
    vmblock driver.
  + vmxnet3 for Linux is now upstream (as of Linux 2.6.32), and
    will be removed from later releases of open-vm-tools.
  + pvscsi will be available upstream starting with Linux 2.6.33
    and at that time will be removed from open-vm-tools.
- Disable building of vmxnet3 if kernel is 2.6.32 or newer.
* Mon Nov 23 2009 dimstar@opensuse.org
- Update to 2009.11.17
  + Lots of refactoring and cleanup in the code, mainly targeting
    the definition of a set of public APIs.
  + vmblock-fuse can now replace the vmblock kernel module for DnD
    operations.
  + Fix some memory leaks in the guestInfo module.
* Sun Nov 22 2009 dimstar@opensuse.org
- Update to 2009.10.15
  + The HGFS module got some performance enhancements.
  + Minor enhancements to vmtoolsd and the logging system.
  + Fix for a few issues reported on the sourceforge bug tracker.
  + Lots of code refactoring, and a few bug fixes.
* Sat Nov 21 2009 dimstar@opensuse.org
- Update to 2009.09.18
  + Mostly bug fixes and minor enhancements.
  + The pvscsi code was re-factored in preparation for upstreaming.
    The driver has been sent to the LKML for inclusion in the main
    Linux tree and might be removed from open-vm-tools once it's
    accepted.
* Mon Aug 10 2009 dimstar@opensuse.org
- Update to 2009.08.24
  + Remove support for Linux kernels < 2.6.9.
  + The vsock now implements a new notification protocol that has
    better performance than the previous.
  + New infrastructure for sending more network config-related
    information about the virtual machine to the host.
  + Other bug fixes and minor improvements to the code.
* Sat Aug  8 2009 dominique-obs@leuenberger.net
- move libguestlib.so to the devel pakage, which we have since
  version 2009.07.22 and remove the rpmlint check for it.
- Remove the autoreconf call. We do not patch any Makefiles anymore.
- Require libvmtools0 from the -devel package.
- Drop the rpmlintrc file. Permissions are correctyl set, devel
  package split out.
* Thu Aug  6 2009 meissner@suse.de
- Adjust specfile permission handling to match SUSE standard, snippet
  moved to permissions package. bnc#474285
* Thu Jul 23 2009 dominique-obs@leuenberger.net
- Update to 2009.07.22
  * Better support for dkms by means of a script to help create a
    dkms tree.
  * "make install" now also installs header files for public
    libraries, plus a few fixes to incorrect install behavior.
  * Lots of improvements to the new DnD code.
  * This will be the last release with support for Linux
    kernels < 2.6.9.
- fix compatibiliy update script to redirect stderr to /dev/null
  (in case the script is not found, do not scare the user)
* Tue Jul 21 2009 prusnak@suse.cz
- added || : to modprobe -r and umount calls in vmtoolsd [bnc#523342]
* Fri Jun 19 2009 dominique-obs@leuenberger.net
- Updated to 2009.06.18
  * Mostly a bug fix release.
  * vmhgfs now is able to use vsock as a transport (although
    backend support for HGFS over vsock is not yet released in
    VMware products).
- Removed patch open-vm-tools-wiperPosix.patch. An alternative
  solution was integrated upstream
- Dropped patch open-vm-tools-rpath.patch: merged upstream
* Sat May 23 2009 dominique-obs@leuenberger.net
- Updated to 2009.05.22
  * Mostly a cleanup and bug fix release.
  * Fix a build issue where a symlink attack could cause the
    open-vm-tools build to overwrite data (by placing a symlink in
    /tmp).
  * Second (and last?) batch of changes to clean up duplicate files
    in the source tree, including Solaris and FreeBSD kernel
    modules andother module-specific shared files.
  * Plugins now are properly built using plugins_LTLIBRARIES so
    that "-rpath" doesn't need to be used (this would cause an
    RPATH entry to be added to the final binary, which some tools
    didn't like).
  * open-vm-tools now properly detects PAM and enables PAM support
    in the code.
- Removed -rpath.patch. Variation of it integrated upstream
- Added patch to consume (-wiperPosix.patch) the result of fgets
- BuildRequires pam-devel
- The pam miss-naming on x86_64 has been fixed upstream
- Add a new -rpath patch. Not everything is solved upstream.
- Delete arch dependent files from /usr/share (not yet needed)
* Sat Apr 25 2009 dominique.leuenberger@tmf-group.com
- Upgrade to snapshot 2009.04.23
  * Implemented copy & paste support for RTF data and file contents.
  * guestd has been removed from open-vm-tools; vmtoolsd is now the only
    option for the main tools service.
  * Added vmblock and vmmemctl modules for Solaris (under the CDDL).
  * vmware-user can now work with both vmblock-fuse and vmblock.
  * Linux HGFS now has a stream-based (TCP, vsock) transport, still under
    development.
  * First batch of changes to cleanup duplicated files in the source tree.
    Most duplicated files in the Linux kernel modules have been cleaned up.
- Extensive rewrite of the spec file:
  * make use of the now upstream provided make install
  * configure --no-root-privileges, to not install mount.vmhgfs as suid
- Add patch open-vm-tools-2009.04.23-rpath.diff: removes the rpath logic
  which was introduced for the vmusr and vmsvc plugins. libtools is broken
  in this respect. (patch submitted upstream for review)
- Extend preun section with  service rename (vmware-guest -> vmtoolsd)
  (patch provided by prusnak)
- forcibly activate vmtoolsd service also on update.
- fix up the KMP rename: for this to work we need to provide / obsolete
  vmware-kmp and vmware-kmp-<kernelflavor>; otherwise, zypper starts pulling
  in other kernels.
* Fri Mar 20 2009 dominique@leuenberger.net
- rename vmware-KMP to vmware-guest-KMP for easier identification
  of the use and to avoid confusion (users installing the KMP on the
  vmware hosts) (bnc#481137)
- create subpackage libvmtools0
* Thu Mar 19 2009 dominique@leuenberger.net
- Upgrade to snapshot 2009.03.18
  * Mostly a bug fix release.
  * The new DnD V3 protocol is now available in open-vm-tools.
  * vmtoolsd is now preferred instead of vmware-guestd
  - vmware-guestd will most probably be completely removed in the next release.
  - > vmtoolsd is not yet standard enabled in openSUSE packages.
- Obsolete merged patches vmxnet and vmxnet3.patch.
* Mon Mar  9 2009 mmarek@suse.cz
- renamed modprobe config to /etc/modprobe.d/50-vmnics.conf
  (required by new module-init-tools).
* Thu Feb 19 2009 dominique@leuenberger.net
- Upgrade to snapshot 2009.02.18
  * open-vm-tools now depend on glib 2.6.0 as a minimum requirement.
  * Added vmxnet module for Solaris, and reworked the HGFS module so it
    works without help from vmware-guestd.
  * Added implementation of new DnD protocol, which adds a dependency on
    a C++ compiler and the gtkmm library to vmware-user.
  * The code from the "core services" has been added to open-vm-tools,
    including a few tests. vmtoolsd + plugins are now capable of replacing
    vmware-guestd (vmware-user still needs to have some features ported
    over), but this code is still not to be considered as stable as the
    legacy services, so vmware-guestd is still included.
  * A few fixes for compatibility with non-GNU toolchains, newer Linux
    kernels and old gcc compilers.
- Added patch open-vm-tools-2009.02.18-vmxnet.patch
  Allows to compile kernelmodule vmxnet with kernels 2.6.29
  And open-vm-tools02009.02.18-vmxnet3.patch
* Mon Feb 16 2009 dominique@leuenberger.net
- Remove noDisplay=true from vmware-user.desktop, as KDE4
  does not autostart the app in this case. Fixes BNC #475627
* Thu Feb 12 2009 dominique@leuenberger.net
- Added vmware-user-autostart-wrapper to solve bnc #474076
  Using simple autostart technique, it can happen that the device
  at /proc/fs/vmblock/dev is not ready when vmware-user is started
  the autostart-wrapper takes this into account and tries for
  several times.
- Fix RPMLint warning with regarding wrong encoding of README file
* Wed Feb 11 2009 dominique@leuenberger.net
- Revert suid install of vmware-user-suid-wrapper, as rpmlint does
  not like it
  Instead we package /etc/permissions.d/open-vm-tools which sets
  the permission usig SuSEconfig.permissions
- Adjust the vmware-user.desktop file to actually launch
  vmware-user-suid-wrapper. Access to the vmblock requires su right.
  the suid-wrapper get's the file handle, drops the suid rights
  and launches vmware-user (with user privileges)
* Tue Feb 10 2009 prusnak@suse.cz
- install vmware-user-suid-wrapper with suid bit
* Mon Jan 26 2009 prusnak@suse.cz
- reviewed changes by Dominique
* Thu Jan 22 2009 dominique@leuenberger.net
- Update to version 2009.01.21
  * First open source release of the HGFS module for Solaris,
    under the CDDL. Other modules are expected to be added in
    the upcoming releases.
  * Added an implementation of vmblock on top of FUSE;
    vmware-user still  doesn't use this module even if it is
    available, though.
  * Linux modules now add the "supported" tag used by Novell in
    their SLES 10 SP2 release when loading modules.
  * Fix compilation of modules in newer Linux kernels which
    don't include $(LINUXINCLUDE) in the compiler flags anymore.
- Added Requires: kernel-%%1 to preamble, as rpmlint said it would
  be policy to require kenrel-$favour from the kmp
- marked config files in /etc as %%config (rpmlint)
* Fri Jan 16 2009 prusnak@suse.cz
- reviewed changes by Dominique
* Thu Dec 25 2008 dominique@leuenberger.net
- Update to version 2008.12.23
  * Lots of makefile cleanup with the switch to using libtool archives.
  * Automatically disable Unity if multimon support is disabled.
  * Actually build the pvscsi modules.
  * First bits of the "Core Service" project are starting to show up; the
    base "vmtools" library was added to the package. It currently is mostly
    a collection of the existing libraries already shipped with open-vm-tools,
    plus some extra functionality build on top of glib. Currently no other
    code in open-vm-tools uses it, so it's optional.
  * The HGFS driver was fixed for the Linux 2.6.28 kernel.
* Wed Nov 19 2008 dominique@leuenberger.net
- Updated to version 2008.11.19
  * The pvscsi Linux kernel module has been added (for kernels >= 2.6.8).
    It provides access to VMware's new paravirtualized SCSI device.
  * The HGFS driver and user-level code has seen a lot of refactoring to
    enable more consistent name escaping. The FreeBSD driver now supports
    symlinks.
  * The Linux module makefiles now support exporting symbol version files,
    allowing modules with dependencies (such as vsock, which depends on vmci)
    to correctly build and load on Linux >= 2.6.26 with CONFIG_MODVERSIONS.
  * Rudimentary support for dkms.
  * Assortment of bug fixes.
* Wed Oct 15 2008 dominique@leuenberger.net
- Updated to version 2008.10.10
  * The vmxnet3 Linux kernel module has been added. This module provides
    better network performance for the guest. The corresponding virtual
    hardware is available beginning with Workstation 6.5, though
    performance benefits are unlikely to be realized until a later VMware
    product release. The module should work for all kernels beginning with
    2.6.
  * The open-vm-tools no longer depend on libproc-dev. Several people
    reported this issue (Sourceforge bug 1960947).
  * Added a command line argument to skip privileged operations during
    make install (--without-root-privileges).
  * Guestd now supports backwards time synchronization, though the
    corresponding hypervisor-side changes are not yet part of any shipping
    VMware products.
  * Assortment of bug fixes.
* Wed Sep 17 2008 prusnak@suse.cz
- fixed license problem with region.c by applying patch from upstream
* Mon Sep  8 2008 dominique@leuenberger.net
- Removed patch kver.patch, refactored it's function in the
  make call, overriding the HEADER_DIR variable inside the
  Makefile (Tip sponsored by Adar from VMware Inc.)
* Thu Sep  4 2008 prusnak@suse.cz
- reviewed changes by Dominique
* Wed Sep  3 2008 dominique@leuenberger.net
- Activated compilation of modules vmci and vsock after fixing the
  kver.patch
- dropped obsoleted patch:
  * str_c.patch (included in update)
* Wed Sep  3 2008 prusnak@suse.cz
- updated to 2008-09-03
  * Fixed an issue where open-vm-tools fails to configure when using
  - -without-icu. Thanks to Timo Gurr for reporting the issue
    (Sourceforge bug 2046262).
  * Fixed failed build on Ubuntu Intrepid and Fedora 9.
    Thanks to Nathan Charles for reporting the issue
    (Sourceforge bug 2048423).
  * Fixed kernel module build issues on 2.6.27 pre-release kernels.
    Thanks to Dominique Leuenberger for reporting the issue
    (Sourceforge bug 2071170).
  * ...and other bug fixes.
- dropped obsoleted patches:
  * 2.6.27-kernel.patch (included in update)
  * fix-Werror.patch (included in update)
* Sun Aug 24 2008 dominique@leuenberger.net
- Added open-vm-tools-2008-08-08-2.6.27-kernel.patch to compile on
  more recent kernels (patch should be merged in next release)
* Fri Aug 22 2008 dominique@leuenberger.net
- added packageand(open-vm-tools:xorg-x11) to Supplements
  of open-vm-tools-gui sub package
* Fri Aug 22 2008 dominique@leuenberger.net
- Re-arranged comments for the configure line. Apparently, comments
  that appear in a line continuing on the next line, split using '\'
  break the flow
* Wed Aug 20 2008 dominique@leuenberger.net
- Added --without-kernel-modules to configure, as we take
  care of it on ourself using the loop, for the different
  kernel variants
* Tue Aug 12 2008 prusnak@suse.cz
- updated to 2008.08.08
  * Unity for X11 guests has been added. Unity is implemented within
    vmware-user and requires no additional setup beyond setting up the
    vmware-user application itself. Unity should work with Fusion 1.x
    releases as well as with the upcoming Workstation 6.5 release. Our
    in-house testing was with Linux guests, and they should mostly work.
    There is very little standing in the way of FreeBSD/Solaris support,
    though we've never built or tested Unity for those platforms.
  * The VMCI Linux kernel module has been added. This module provides
    high-speed datagram and socket interfaces for guest<->guest and
    host<->guest communication. It should work for all kernels beginning
    with 2.4, and for VMware products beginning with Workstation 6.5.
  * The VMCI sockets Linux kernel module has been added. It provides
    both datagram and stream socket interfaces to userlevel for use with
    VMCI. As with VMCI, it should work for kernels 2.4 or later, and for
    VMware products beginning with Workstation 6.5.
  * The command-line Toolbox has been added. This application provides
    the same functionality as the GTK Toolbox, but with a scriptable
    command-line interface. It also has some statistic retrieval commands
    that aren't found in the GTK Toolbox.
  * Fixed compilation of vmsync and vmmemctl Linux kernel modules on
    2.6.26. Thanks to Pavol Rusnak for the report (Sourceforge bug 2032683).
  * Fixed an issue with guestd's nicInfo updating mechanism. Thanks to
    Jason Lunz for the patch (not tracked on Sourceforge).
  * Fixed handling of $(DESTDIR) in automake. Thanks to Mike Auty for
    the patch (Sourceforge bug 2018802).
  * Fixed build of vmware-user using gtk 1.2. Thanks to Stephen Duncan
    for the report (Sourceforge bug 2014338).
  * Fixed compilation of lib/guestApp when using --without-x. Thanks to
    Martin Preishuber for the report (Sourceforge bug 2013568).
  * As usual, other bug fixes.
* Mon Jul 21 2008 prusnak@suse.cz
- updated to 2008.07.01:
  * fixed a backwards time synchronization issue
  * fixed an issue where open-vm-tools configured via --without-x didn't
    compile (not tracked on Sourceforge)
  * one can now pass --without-kernel-modules, --with-kernel-release, and
  - -with-linuxdir to the ./configure script
  * other bug fixes.
- branched open-vm-tools-gui subpackage with tools that need X
* Thu Jun 12 2008 prusnak@suse.cz
- open-vm-tools now requires vmware-kmp [bnc#397972]
- exclude AMD PCnet32 LANCE pci.id from Supplements list [bnc#397554]
* Mon Jun  9 2008 dominique-obs@leuenberger.net
- Updated to version 2008.06.03
  adopted spec file to new build structure layout (the binaries
  are now named correctly just after build and do not need to
  be renamed anymore)
- Replaced -werror patch with -fix-Werror-patch (submitted to
  VMware for inclusion)
* Mon Jun  2 2008 prusnak@suse.cz
- updated vmware init-script [bnc#394431]:
  * check whether /tmp/VMwareDnD exists and create it if necessary
  * use modules vmblock, vmmemctl, vmsync for better performance
  * mount the virtual system for Drag'n'Drop
* Wed May 28 2008 dominique-rpm@leuenberger.net
- Excluded the building of KMPs for XEN, probably nobody installs
  a vmware host in xen.
* Thu May 22 2008 prusnak@suse.cz
- added Recommends: open-vm-tools to KMP preamble [bnc#391434]
- added -y to %%fillup_and_insserv macro, so the service starts
  automatically [bnc#391434]
* Tue May 20 2008 dominique-rpm@leuenberger.net
- replaced %%build section with the one from openSUSE internal
  stable build, for building properly against all buildtargets
* Tue May 20 2008 dominique-rpm@leuenberger.net
- Added preamble for %%suse_kernel_module_package in order to have
  a Recommends: open-vm-tools on the kmp.
  The KMP is installed by Supplements: the hardware ID, and the KMP
  then pulls in the open-vm-tools package by Recommends (if available)
* Wed May  7 2008 dominique-rpm@leuenberger.net
- Updated to 2008.05.15:
  * Removed "blessed app" code for starting vmware-user
  * lib/file/filePosix.c: Use new Posix_RealPath implementation.
  * Cleanup UTF-8 handling.
* Wed May  7 2008 dominique-rpm@leuenberger.net
- Added patch open-vm-tools-2008.05.02-str.c that should solve
  compilation with FORTIFY_SOURCE enabled
* Tue May  6 2008 prusnak@suse.cz
- updated to 2008.05.02:
  * continued Unicode support
  * open-vm-tools now depends on libicu for codeset conversions
  * a few more bug fixes
* Mon Apr 28 2008 ro@suse.de
- tweak build section long enough to really build modules
  matching to kernel flavour (and not just build all for -default)
  (bnc#384192)
* Wed Apr 23 2008 ro@suse.de
- added vmware-KMP package and description tags to specfile
- added preable file for kmp packages
* Wed Apr 23 2008 prusnak@suse.cz
- fixed %%verifyscript
* Tue Apr 22 2008 prusnak@suse.cz
- updated to 2008.04.14
  * continued Unicode support
  * more bug fixes, including a security fix in guestd
- added permissions scripts to %%post section
* Tue Mar 25 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.19
* Thu Mar 20 2008 prusnak@suse.cz
- add Supplements to automatically install in VMware
* Tue Mar 18 2008 prusnak@suse.cz
- first autobuild checkin
- turn off -Werror (werror.patch)
- reworked spec file
* Fri Mar 14 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.11
  (developer snapshot to support all modules on 2.6.25 kernels)
* Tue Mar 11 2008 dominique-rpm@leuenberger.net
- updated to 2008.03.10
  (developer snapshot to support kernel version 2.6.25-rc1)
* Sun Mar  9 2008 dominique-rpm@leuenberger.net
- refactored open-vm-tools-kver.patch to detect the kernel source
  correctly
* Sat Mar  8 2008 dominique-rpm@leuenberger.net
- create link from /sbin/rcvmware to /etc/init.d/vmware-guest
- autostart the service after installation
* Sat Mar  8 2008 dominique-rpm@leuenberger.net
- initial build of open-vm-tools
- builds kmps and open-vm-tools
